@@ -298,6 +298,9 @@ class e01700(Variable):
     unit = USD
 
 
+pension_income = variable_alias("pension_income", e01700)
+
+
 class filer_e01700(Variable):
     value_type = float
     entity = TaxUnit
@@ -358,7 +361,10 @@ class e02300(Variable):
     unit = USD
 
 
-class filer_e02300(Variable):
+unemployment_insurance = variable_alias("unemployment_insurance", e02300)
+
+
+class tax_unit_ui(Variable):
     value_type = float
     entity = TaxUnit
     definition_period = YEAR
@@ -366,7 +372,10 @@ class filer_e02300(Variable):
     unit = USD
 
     def formula(tax_unit, period, parameters):
-        return tax_unit_non_dep_sum("e02300", tax_unit, period)
+        return tax_unit_non_dep_sum("unemployment_insurance", tax_unit, period)
+
+
+filer_e02300 = variable_alias("filer_e02300", tax_unit_ui)
 
 
 class e02400(Variable):
@@ -380,7 +389,7 @@ class e02400(Variable):
         return person("social_security", period)
 
 
-class filer_e02400(Variable):
+class tax_unit_ss(Variable):
     value_type = float
     entity = TaxUnit
     label = "Social security benefits for the tax unit (excluding dependents)"
@@ -388,7 +397,10 @@ class filer_e02400(Variable):
     unit = USD
 
     def formula(tax_unit, period, parameters):
-        return tax_unit_non_dep_sum("e02400", tax_unit, period)
+        return add(tax_unit, period, ["social_security"])
+
+
+filer_e02400 = variable_alias("filer_e02400", tax_unit_ss)
 
 
 class e03150(Variable):
@@ -634,25 +646,6 @@ class filer_e17500(Variable):
         return tax_unit_non_dep_sum("e17500", tax_unit, period)
 
 
-class e18400(Variable):
-    value_type = float
-    entity = Person
-    definition_period = YEAR
-    documentation = "Itemizable state and local income/sales taxes"
-    unit = USD
-
-
-class filer_e18400(Variable):
-    value_type = float
-    entity = TaxUnit
-    label = "Itemized SALT for the tax unit (excluding dependents)"
-    definition_period = YEAR
-    unit = USD
-
-    def formula(tax_unit, period, parameters):
-        return tax_unit_non_dep_sum("e18400", tax_unit, period)
-
-
 class e18500(Variable):
     value_type = float
     entity = Person
@@ -815,7 +808,7 @@ class e26270(Variable):
     documentation = "Sch E: Combined partnership and S-corporation net income/loss (includes k1bx14p and k1bx14s amounts and is included in e02000)"
 
 
-class filer_e26270(Variable):
+class filer_partnership_s_corp_income(Variable):
     value_type = float
     entity = TaxUnit
     label = "Partnership/S-corp income for the tax unit (excluding dependents)"
@@ -826,9 +819,7 @@ class filer_e26270(Variable):
         return tax_unit_non_dep_sum("e26270", tax_unit, period)
 
 
-filer_partnership_s_corp_income = variable_alias(
-    "filer_partnership_s_corp_income", filer_e26270
-)
+filer_e26270 = variable_alias("filer_e26270", filer_partnership_s_corp_income)
 
 
 class e27200(Variable):
@@ -878,6 +869,11 @@ class filer_e32800(Variable):
         return tax_unit_non_dep_sum("e32800", tax_unit, period)
 
 
+tax_unit_childcare_expenses = variable_alias(
+    "tax_unit_childcare_expenses", filer_e32800
+)
+
+
 class e58990(Variable):
     value_type = float
     entity = Person
@@ -1110,6 +1106,9 @@ class p22250(Variable):
     unit = USD
 
 
+short_term_capital_gains = variable_alias("short_term_capital_gains", p22250)
+
+
 class filer_p22250(Variable):
     value_type = float
     entity = TaxUnit
@@ -1131,6 +1130,9 @@ class p23250(Variable):
     unit = USD
 
 
+long_term_capital_gains = variable_alias("long_term_capital_gains", p23250)
+
+
 class filer_p23250(Variable):
     value_type = float
     entity = TaxUnit
