@@ -56,7 +56,7 @@ class filer_earned(Variable):
     unit = USD
 
     def formula(tax_unit, period, parameters):
-        return tax_unit_non_dep_sum("earned", tax_unit, period)
+        return max_(0, tax_unit_non_dep_sum("earned", tax_unit, period))
 
 
 class earned(Variable):
@@ -76,10 +76,9 @@ class earned(Variable):
             * misc.employer_share
             * person("self_employment_tax", period)
         )
-        return max_(
-            0,
-            add(person, period, ["e00200", "self_employment_tax"])
-            - adjustment,
+        return (
+            add(person, period, ["e00200", "self_employment_income"])
+            - adjustment
         )
 
 
@@ -99,7 +98,9 @@ class sep(Variable):
     entity = TaxUnit
     definition_period = YEAR
     default_value = 1
-    documentation = "2 when MARS is 3 (married filing separately); otherwise 1"
+    documentation = (
+        "2 when filing_status is 3 (married filing separately); otherwise 1"
+    )
 
 
 class surtax(Variable):
@@ -218,8 +219,8 @@ class tax_unit_is_joint(Variable):
     definition_period = YEAR
 
     def formula(tax_unit, period, parameters):
-        mars = tax_unit("mars", period)
-        return mars == mars.possible_values.JOINT
+        filing_status = tax_unit("filing_status", period)
+        return filing_status == filing_status.possible_values.JOINT
 
 
 class care_deduction(Variable):
