@@ -18,6 +18,6 @@ class niit(Variable):
         ]
         nii = max_(0, add(tax_unit, period, NII_ELEMENTS))
         niit = parameters(period).irs.investment.net_inv_inc_tax
-        threshold = niit.threshold[tax_unit("mars", period)]
+        threshold = niit.threshold[tax_unit("filing_status", period)]
         base = min_(nii, max_(0, tax_unit("c00100", period) - threshold))
         return niit.rate * base
