@@ -12,6 +12,6 @@ class is_ca_cvrp_normal_rebate_eligible(Variable):
     def formula(person, period, parameters):
         # AGI must be less than the threshold.
         agi = person.tax_unit("c00100", period)
-        mars = person.tax_unit("mars", period)
+        filing_status = person.tax_unit("filing_status", period)
         caps = parameters(period).states.ca.calepa.carb.cvrp.income_cap
-        return agi <= caps[mars]
+        return agi <= caps[filing_status]
